"use client";

import Image from "next/image";
import { useCallback, useEffect, useState } from "react";

import useEmblaCarousel from "embla-carousel-react";
import { ArrowLeft, ArrowRight } from "lucide-react";

import { ContentLines } from "@/components/shared/content-lines";
import { Button } from "@/components/ui/button";
import { Card, CardContent, CardHeader } from "@/components/ui/card";
import { ImageBaseUrl } from "@/configs/api";
import { Link, Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { useBasicInfo } from "@/servers/data/use-basicinfo";
import { useLocale, useTranslations } from "next-intl";

export default function BlogClient() {
	const t = useTranslations();
	const locale = useLocale() as Locale;
	const isRTL = locale === "ar";

	const { texts } = useBasicInfo();

	const [emblaRef, emblaApi] = useEmblaCarousel({
		align: "start",
		direction: isRTL ? "rtl" : "ltr",
		breakpoints: {
			"(min-width: 768px)": { slidesToScroll: 2 },
			"(min-width: 1024px)": { slidesToScroll: 3 },
		},
	});

	const [canScrollPrevious, setCanScrollPrevious] = useState(false);
	const [canScrollNext, setCanScrollNext] = useState(true);

	const scrollPrevious = useCallback(
		() => emblaApi && emblaApi.scrollPrev(),
		[emblaApi]
	);
	const scrollNext = useCallback(
		() => emblaApi && emblaApi.scrollNext(),
		[emblaApi]
	);

	const onSelect = useCallback(() => {
		if (!emblaApi) return;
		setCanScrollPrevious(emblaApi.canScrollPrev());
		setCanScrollNext(emblaApi.canScrollNext());
	}, [emblaApi]);

	useEffect(() => {
		if (!emblaApi) return;
		onSelect();
		emblaApi.on("select", onSelect);
		emblaApi.on("reInit", onSelect);
		return () => {
			emblaApi.off("select", onSelect);
			emblaApi.off("reInit", onSelect);
		};
	}, [emblaApi, onSelect]);


	return (
		texts?.company_news?.length > 0 &&
		<section className="px-4 py-16 md:px-8 lg:px-40">
			{/* Header */}
			<div className="mb-12 flex flex-col items-center justify-between gap-8 md:flex-row">
				<Button
					variant="outline"
					size="icon"
					className="order-2 rounded-full border-blue-500 text-blue-500 hover:bg-blue-50 md:order-1"
					onClick={isRTL ? scrollNext : scrollPrevious}
					disabled={isRTL ? !canScrollNext : !canScrollPrevious}
				>
					{isRTL ? (
						<ArrowRight className="text-[#0575DA]" />

					) : (
						<ArrowLeft className="text-[#0575DA]" />

					)}
				</Button>

				<div className="order-1 text-center md:order-2">
					<ContentLines
						title={t("Company News")}
						underlineColor="custom-primary-accent"
						centered
						textColor="text-custom-primary-accent"
					/>
					<h2 className="mb-4 mt-6 text-4xl font-bold">
						{texts?.company_news_section_title?.[locale]}
					</h2>
					<p className="mx-auto max-w-3xl text-gray-600">
						{texts?.company_news_section_description?.[locale]}
					</p>
				</div>

				<Button
					variant="outline"
					size="icon"
					className="order-3 rounded-full border-blue-500 text-blue-500 hover:bg-blue-50"
					onClick={isRTL ? scrollPrevious : scrollNext}
					disabled={isRTL ? !canScrollPrevious : !canScrollNext}
				>
					{isRTL ? (
						<ArrowLeft className="text-[#0575DA]" />
					) : (

						<ArrowRight className="text-[#0575DA]" />
					)}
				</Button>
			</div>

			{/* Blog Posts Slider */}
			<div className="overflow-hidden" ref={emblaRef}>
				<div className="flex justify-center">
					{texts?.company_news?.filter((item) => item.status === "on")
						?.map(({ image, text, writing_date, description, author_name }, index) => (
							<div
								key={index}
								className="min-w-0 flex-[0_0_100%] px-4 md:flex-[0_0_50%] lg:flex-[0_0_33.333%]"
							>
								<Card className="h-full overflow-hidden rounded-lg border-none">
									<div className="relative aspect-[16/9]">
										<Image
											src={ImageBaseUrl + image}
											alt={text?.[locale]}
											fill
											className="object-cover"
										/>
									</div>
									<CardHeader className="flex-row items-center justify-between">
										<div className="text-sm text-gray-500">
											{writing_date}
										</div>
										<div className="text-sm text-gray-500">
											{author_name?.[locale]}
										</div>
									</CardHeader>
									<CardContent>
										<h3
											className={cn(
												"mb-2 text-md text-center font-bold text-custom-primary-accent",
											)}
										>
											{text?.[locale]}
										</h3>
										<p
											className={cn(
												"text-[#606676] text-center text-[15px]",
											)}
										>
											{`${description?.[locale]?.slice(0, 220)}.....`}
										</p>
										<div className="flex justify-center">
											<Button variant="default" className="mt-4 bg-custom-secondary text-white text-center"
												asChild>
												<Link href={`/blogs/${text?.[locale]?.trim().replace(/\s+/g, "-")}` as any}>
													{t("Read More")}
												</Link>
											</Button>
										</div>
									</CardContent>
								</Card>
							</div>
						))}
				</div>
			</div>
		</section>
	);
}
